@@ -19,7 +19,7 @@ car.alpha = rabbyt.lerp(0.0, 1.0, startt=1000, endt=2000)
 # Rotate the car from 0 to 360 over three seconds, then repeat.
 car.rot = rabbyt.lerp(0, 360, dt=3000, extend="repeat")
 
-while True:
+while not pygame.event.peek(pygame.QUIT):
     rabbyt.clear((1,1,1))
 
     # When using dynamic values (such as returned by lerp,) we need to tell
