@@ -25,7 +25,9 @@ while running:
     clock.tick(40)
 
     for event in pygame.event.get():
-        if event.type == pygame.KEYDOWN:
+        if event.type == pygame.QUIT:
+            running=False
+        elif event.type == pygame.KEYDOWN:
             if event.key in (pygame.K_ESCAPE, pygame.K_q):
                 running=False
         elif event.type == pygame.MOUSEBUTTONDOWN:
